@@ -6,7 +6,7 @@ use vars qw[$VERSION %utilities];
 use Module::CoreList;
 use Module::CoreList::TieHashDelta;
 
-$VERSION = '5.20160520';
+$VERSION = '5.20160620';
 
 sub utilities {
     my $perl = shift;
@@ -1164,6 +1164,13 @@ my %delta = (
         removed => {
         }
     },
+    5.025002 => {
+        delta_from => 5.025001,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 for my $version (sort { $a <=> $b } keys %delta) {
